pitchtools.transpose_chromatic_pitch_number_by_octave_transposition_mapping
===========================================================================

.. autofunction:: abjad.tools.pitchtools.transpose_chromatic_pitch_number_by_octave_transposition_mapping.transpose_chromatic_pitch_number_by_octave_transposition_mapping
